{"version":1,"type":"collection","title":"2ic Altair Example","queries":[{"version":1,"type":"window","query":"# Note: all queries are filtered to records that your current login/access_token is authorised to view.\n\n# Returns a list of all locations in the pallets database, sorted by kind\nquery GetLocations($sortByLocationKind: LocationQueryInput!) {\n  locations(input: $sortByLocationKind) {\n    content {\n      totalCount\n      items {\n        id\n        name\n        kind\n      }\n    }\n    messages {\n      kind\n      key\n      targets\n      arguments {\n        name\n        value\n      }\n    }\n  }\n}\n\n# Returns a list of all locations of a specified kind\nquery GetLocationsFromKind($filterByLocationKind: LocationQueryInput!) {\n  locations(input: $filterByLocationKind) {\n    content {\n      totalCount\n      items {\n        id\n        name\n        kind\n      }\n    }\n    messages {\n      kind\n      key\n      targets\n      arguments {\n        name\n        value\n      }\n    }\n  }\n}\n\n# Returns a list of all accounts in the pallets database\nquery GetAccounts($noFiltering: AccountQueryInput!) {\n  accounts(input: $noFiltering) {\n    content {\n      totalCount\n      items {\n        id\n        name\n      }\n    }\n    messages {\n      kind\n      key\n      targets\n      arguments {\n        name\n        value\n      }\n    }\n  }\n}\n\n# Returns a list of all products in the pallets database\nquery GetProducts($noFiltering: ProductQueryInput!) {\n  products(input: $noFiltering) {\n    content {\n      totalCount\n      items {\n        id\n        name\n      }\n    }\n    messages {\n      kind\n      key\n      targets\n      arguments {\n        name\n        value\n      }\n    }\n  }\n}\n\n# Returns a list of the top 1000 transactions ordered by SendingDate (only some fields selected)\nquery GetTransactions($sortBySendingDate: TransactionQueryInput!) {\n  transactions(input: $sortBySendingDate) {\n    content {\n      totalCount\n      items {\n        id\n        sendingDate\n        account { id name }\n        product { id name }\n        senderLocation { id name }\n        receiverLocation { id name }\n        quantity\n        kind\n\n        effectiveDate\n        isExported\n        isComplete\n        isCancelled\n      }\n    }\n    messages {\n      kind\n      key\n      targets\n      arguments {\n        name\n        value\n      }\n    }\n  }\n}\n\n# Creates a new transaction\n# Note: to create a transaction, specify ID values for: account, product and sender/receiver locations\n# Note: ID and docketNumber field must be updated for each new transaction\nmutation CreateNewTransaction ($transactionInput: CreateTransactionInput!) {\n\tcreateTransaction (input: $transactionInput) {        \n    content\n    messages { kind key targets arguments { name value isValueAKey } }\n  }\n}","apiUrl":"https://api.2icsoftware.com/pallets/graphql","variables":"{\n  \"noFiltering\": {\n    \"filterBy\": [],\n    \"sortBy\": [{ \n      \"field\": \"name\",\n      \"direction\": \"ascending\"\n    }],\n    \"paging\": {\n      \"startRow\": 0,\n      \"endRow\": 1000\n    }\n  },\n  \"sortByLocationKind\": {\n    \"filterBy\": [],\n    \"sortBy\": [{ \n      \"field\": \"name\",\n      \"field\": \"kind\",\n      \"direction\": \"ascending\"\n    }],\n    \"paging\": {\n      \"startRow\": 0,\n      \"endRow\": 1000\n    }\n  },\n  \"filterByLocationKind\": {\n    \"filterBy\": [{\n      \"group\": [{\n        \"item\": {\n          \"conjunction\": \"and\",\n          \"field\": \"kind\",\n          \"operator\": \"equals\",\n          \"stringValue\": \"site\"\n        }}\n        ]\n    }],\n    \"sortBy\": [{ \n      \"field\": \"name\",\n      \"direction\": \"ascending\"\n    }],\n    \"paging\": {\n      \"startRow\": 0,\n      \"endRow\": 1000\n    }\n  },\n  \"sortBySendingDate\": {\n    \"filterBy\": [],\n    \"sortBy\": [{ \n      \"field\": \"sendingDate\",\n      \"direction\": \"ascending\"\n    }],\n    \"paging\": {\n      \"startRow\": 0,\n      \"endRow\": 1000\n    }\n  },\n  \"transactionInput\":{ \n    \n    \"id\":\"265100c5-79d8-2c4d-d6af-f683cff4e4f6\",\n    \"accountId\": \"aeafd4d7-d182-7e55-c928-9519e43fe26a\",\n    \"productId\": \"8d22a601-2568-9062-4e9f-ea3901fe90ee\",\n    \"senderLocationId\": \"78572a5f-7018-9687-c15c-ae02fb72d232\",\n    \"receiverLocationId\": \"ac294392-c17c-6839-55a2-96bfd1c90dad\",\n    \"docketNumber\": \"ABCD12344\",\n    \n    \"sendingDate\":\"2024-01-19\",\n    \"quantity\": 3,\n    \"kind\": \"transferOff\",\n    \"effectiveDate\": \"2024-01-19\",\n    \"isExported\": false,\n    \"isManagedRecovery\": false,\n    \"isComplete\": true,\n    \"isCancelled\": false\n  }\n}\n  \n  ","subscriptionUrl":"wss://pallets-api.2icsoftware.com/graphql","headers":[{"key":"Authorization","value":"Bearer {{access_token}}","enabled":true},{"key":"X-PalletsRunContext-Key","value":"{{database_id}}","enabled":true}],"windowName":"Pallets","preRequestScript":"","preRequestScriptEnabled":false,"id":"cf434889-6c8f-4e90-a9b8-725522f0eabe","updated_at":1705639755120,"created_at":1705639755120,"subscriptionConnectionParams":"{}","postRequestScript":"","postRequestScriptEnabled":false},{"version":1,"type":"window","query":"# Returns a list of accounts, sorted by internalName, where the accountNumber begins with 1 and contains a 6\n# The filtering and sorting criteria can be changed in the filterByAccountNumber variable.\nquery GetAccounts($filterByAccountNumber: AccountQueryInput!) {\n  accounts(input: $filterByAccountNumber) {\n    content {\n        totalCount\n        items {\n            id\n            version\n            internalName\n            accountNumber\n            externalName\n            fullName\n            supplier {\n                kind\n                id\n            }\n            country\n            currencyCode\n            database { id name }\n        }\n    }\n    messages {\n      kind\n      key\n      targets\n      arguments {\n        name\n        value\n      }\n    }\n  }\n}\n\nquery GetDatabases($noFiltering: DatabaseQueryInput!) {\n  databases(input: $noFiltering) {\n    content {\n        totalCount\n        items {\n            id\n            version\n            name\n            status\n            sqlServerName\n            sqlDatabaseName\n        }\n    }\n    messages {\n      kind\n      key\n      targets\n      arguments {\n        name\n        value\n      }\n    }\n  }\n}\n\nquery GetSites($noFiltering: SiteQueryInput!) {\n  sites(input: $noFiltering) {\n    content {\n        totalCount\n        items {\n            id\n            version\n            name\n            database { id name }\n        }\n    }\n    messages {\n      kind\n      key\n      targets\n      arguments {\n        name\n        value\n      }\n    }\n  }\n}","apiUrl":"https://api.2icsoftware.com/accounts/graphql","variables":"{\n  \"filterByAccountNumber\": {\n    \"filterBy\": [{\n      \"group\": [{\n        \"item\": {\n          \"conjunction\": \"and\",\n          \"field\": \"accountNumber\",\n          \"operator\": \"startsWith\",\n          \"stringValue\": \"1\"\n        }},{\n        \"item\": {\n          \"conjunction\": \"and\",\n          \"field\": \"accountNumber\",\n          \"operator\": \"contains\",\n          \"stringValue\": \"6\"\n        }}]\n    }],\n    \"sortBy\": [{ \n      \"field\": \"internalName\",\n      \"direction\": \"ascending\"\n    }],\n    \"paging\": {\n      \"startRow\": 0,\n      \"endRow\": 1000\n    }\n  },\n  \"noFiltering\": {\n    \"filterBy\": [],\n    \"sortBy\": [],\n    \"paging\": {\n      \"startRow\": 0,\n      \"endRow\": 1000\n    }\n  }\n}","subscriptionUrl":"wss://api.2icsoftware.com/graphql","subscriptionConnectionParams":"{}","headers":[{"key":"Authorization","value":"Bearer {{access_token}}","enabled":true},{"key":"X-PalletsRunContext-Key","value":"{{database_id}}","enabled":true}],"windowName":"Accounts","preRequestScript":"","preRequestScriptEnabled":false,"postRequestScript":"","postRequestScriptEnabled":false,"id":"65689725-5727-4e56-93a0-1e7be0f58bb4","created_at":1705641729877,"updated_at":1705641729877}],"created_at":1705639755120,"updated_at":1705641719234,"id":"6152e53a-1472-4b76-a1b9-7cceb991d56b","parentPath":"","collections":[],"preRequest":{"script":"","enabled":false},"postRequest":{"script":"","enabled":false}}